/*
   Simple example of using a GLUT idle event handler
   to create an animation.
*/
#include <windows.h>
#include "glm.h"

// Prototypes for glut callback functions
void display( void );
void reshape(int, int);
void idle(void);            /***** 1.) Declare an idle event handler. ****/

float animationAngle = 0.0; /***** 2.) Declare a global variable to be set by idle event handler. ****/

int windowHeight;  // this is set by the glut reshape() callback function
int windowWidth;   // this is set by the glut reshape() callback function

GLMmodel* model = NULL;

int main(int argc, char** argv)
{
   // Standard GLUT initialization
   glutInit(&argc,argv);
   glutInitDisplayMode (GLUT_DOUBLE | GLUT_RGB | GLUT_DEPTH);
   glutInitWindowSize(500, 500);
   glutInitWindowPosition(150, 150);
   glutCreateWindow("OBJ Model");
   glutDisplayFunc(display);
   glutReshapeFunc(reshape);
   glutIdleFunc(idle);         /***** 3.) Register the idle event handler. ****/

   // Initialize OpenGL state
   glClearColor(1.0, 1.0, 1.0, 1.0); // white background

   glEnable(GL_DEPTH_TEST);

   // We want to see the model as a wire frame.
   glFrontFace(GL_CCW);
   glPolygonMode(GL_FRONT, GL_LINE);
   glPolygonMode(GL_BACK, GL_LINE);

   //glEnable(GL_LIGHTING);
   //glEnable(GL_LIGHT0);

   model = glmReadOBJ("models/apple.obj");  // try changing the model

   glutMainLoop(); // Enter event loop
   return 0;       // We never get here
}//main()


// The display() callback function
void display()
{
   glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);  // clear the window

   // specify the viewport
   glViewport(0, 0, windowWidth, windowHeight); // left, bottom, width, height (in pixels)

   // set up viewing
   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();
   glOrtho(-1.0, 1.0, -1.0, 1.0, -1.0, 1.0);

   glMatrixMode(GL_MODELVIEW);
   glLoadIdentity();

   /**** 5.) Use the variable set by the idle callback function to control the animation. ****/
   glColor3ub(0, 204, 204);
   glmUnitize(model);
   glPushMatrix();
     glRotatef(animationAngle, 0.0, 1.0, 1.0);
     glmDraw(model, GLM_NONE);
   glPopMatrix();

   glutSwapBuffers();  /**** Animations need double buffering! ****/
}//display()



// The reshape() callback function
void reshape(int width, int height)
{
   windowWidth  = width;
   windowHeight = height;

   printf("We got a \"reshape(%d, %d)\" event\n", width, height);

   glutPostRedisplay();
}//reshape()


/**** 4.) Define the idle event handler function. ****/
void idle()
{
   animationAngle += 5.0;  /*** Each time idle() is called, change this global variable. ***/

   //printf("We got a \"idle()\" event, animationAngle = %f\n", animationAngle);

   //glutSetWindow(window);   // NOTE: You need this line if you are using a glui slider!!
   glutPostRedisplay();
}//idle()